proc sgplot data=orion.budget;
series y=yr2003 x=month / name='2003';
series y=yr2004 x=month / name='2004';
xaxis type=discrete;
inset  'This plot illustrates the monthly' 
       'budget values for 2003 and 2004'/
       position=bottom border title='Explanation: ';
title 'Budget by Month';
run;

ods listing style=listing sge=off;
ods graphics / reset=index;
title; footnote;

** 1) Default Plot;
proc sgplot data=orion.clinic_stats;
  title 'Vbar and Vline';
  vbar monyy / response=tot_pts;
  vline monyy / response=num_surg y2axis; 
  xaxis label = 'Month' interval=month fitpolicy=stagger;
  yaxis label='Total Patients' values=(0  to 2000 by 500);
  y2axis label = 'Number Surgeries' values=( 0 to 200 by 20);
run;
quit;

** 2) Inset Statement;
proc sgplot data=orion.clinic_stats;
  title 'Vbar and Vline with Inset';
  vbar monyy / response=tot_pts;
  vline monyy / response=num_surg y2axis; 
  inset "Includes data from Central and East clinics" 
      /border position=top;
  xaxis label = 'Month' interval=month fitpolicy=stagger;
  yaxis label='Total Patients' values=(0  to 2000 by 500);
  y2axis label = 'Number Surgeries' values=( 0 to 200 by 20);
run;
quit;

** 3) Inset with Title;
proc sgplot data=orion.clinic_stats;
  title 'Vbar and Vline with Inset';
  vbar monyy / response=tot_pts;
  vline monyy / response=num_surg y2axis; 
  inset "Includes data from Central and East clinics" 
      /border position=top title='Inset Title';
  xaxis label = 'Month' interval=month fitpolicy=stagger;
  yaxis label='Total Patients' values=(0  to 2000 by 500);
  y2axis label = 'Number Surgeries' values=( 0 to 200 by 20);
run;
quit;

** 4) Inset Value List;
** Create summary statistics;
proc means data=orion.clinic_stats min mean max sum;
  var num_surg;
  output out=work.stats min=minsurg mean=avgsurg max=maxsurg
                        sum=sumsurg;
run;

** Make macro variables from PROC MEANS statistics;
data _null_;
  set work.stats;
    call symput("minsurg",put(minsurg,3.0));
    call symput("avgsurg",put(avgsurg,3.0));
    call symput("maxsurg",put(maxsurg,3.0));
run;

%put minsurg=&minsurg avgsurg=&avgsurg maxsurg=&maxsurg;
   
** Use macro variables in INSET statement; 
ods listing style=listing;
proc sgplot data=orion.clinic_stats;
  title 'Vbar and Vline with Inset';
  vbar monyy / response=tot_pts group=clinic
               fillattrs=(transparency=0.25);
  vline monyy / response=num_surg y2axis group=clinic
                lineattrs=(thickness=3px); 
  inset (" Minimum" = "&minsurg" 
         " Mean" = "&avgsurg" 
         " Max"="&maxsurg") / border
        title='Clinic Surgeries' position=top;
  xaxis label = 'Month' interval=month fitpolicy=stagger;
  yaxis label='Total Patients' values=(0  to 2500 by 500);
  y2axis label = 'Number Surgeries' values=( 0 to 100 by 10);
run;


** 5) Use UNICODE characters or glyphs in the INSET;
/*
http://support.sas.com/documentation/cdl/en/grstatug/61950/HTML/default/n14y94tov3cxxjn1vll5bt19aob6.htm 
*/

ods output BasicMeasures=work.meas;
proc univariate data=sashelp.heart;
  var cholesterol;
run;

data _null_;
  set work.meas;
  if _n_ = 1;
  if LocMeasure = "Mean" then
     call symput('mn',put(LocValue,best8.));
  if VarMeasure = "Std Deviation" then
     call symput('sd',put(VarValue,best8.));
run;
%let mn = &mn;
%let sd = &sd;
%put mean=&mn stddev=&sd;

ods escapechar='~';
title 'Histogram and Density -- Framingham Heart Study';
proc sgplot data = sashelp.heart;
   histogram cholesterol;
   density cholesterol / type = normal;
   density cholesterol / type = kernel;
   inset ("~{unicode mu}"="&mn" "~{unicode sigma}"="&sd") / 
         position=topright border;
run;

** Housekeeping;

title; footnote;
options nodate nonumber center;
ods graphics / reset=index;
ods graphics off;
ods listing style=listing;



