﻿** high-low chart;
** xaxistable illustrated with highlow;

/*
http://support.sas.com/rnd/datavisualization/yourGraphs/analyticalQuick/timeseries/
https://blogs.sas.com/content/graphicallyspeaking/2017/09/27/stock-chart/
Bollinger band/moving average: https://support.sas.com/resources/papers/proceedings09/324-2009.pdf 
http://support.sas.com/resources/papers/proceedings17/0340-2017.pdf
*/

/* Open the LISTING destination and assign the LISTING style to the graph */
ods listing style=listing;
ods graphics / width=5in height=2.81in;
title 'Monthly Stock Price';

/* no label */
proc sgplot data=sashelp.stocks(where=(stock eq 'IBM' and date > '01Jan2003'd ));
  highlow x=date high=high low=low / open=open close=close
    lineattrs=(thickness=2) y2axis;
  xaxis display=(nolabel);
  y2axis display=(nolabel) grid;
run;

/* with label -- too many points*/
proc sgplot data=sashelp.stocks(where=(stock eq 'IBM' and date > '01Jan2003'd ));
  highlow x=date high=high low=low / open=open close=close
    lineattrs=(thickness=2) y2axis highlabel=high 
    LABELATTRS=(Color=blue Family=Arial Size=1pt 
        Style=Italic Weight=Bold);
  xaxis display=(nolabel);
  y2axis display=(nolabel) grid;
run;

data adjhigh;
  set sashelp.stocks(where=(stock eq 'IBM' and date > '01Jan2003'd ));
  if month(date) in (1 4 7 10) ;
  hilabel = high;
  format hilabel 6.2 ;
run;;

/* adjust labelattrs */
proc sgplot data=adjhigh;
  highlow x=date high=high low=low / open=open close=close
    lineattrs=(thickness=2) y2axis highlabel=hilabel 
    LABELATTRS=(Color=blue Family=Arial Size=2pt 
        Style=Italic Weight=Bold);
  xaxis display=(nolabel);
  y2axis display=(nolabel) grid;
  xaxistable high low close/ valueattrs=(color=blue size=3pt);
run;
 
** With XAXISTABLE and GROUP=STOCK;
ods listing style=htmlblue;
data grpstocks;
  set sashelp.stocks(where=(stock in ( 'IBM' 'Intel') and date > '01Jan2005'd ));
  if month(date) le 7;
  hilabel = high;
  format hilabel 6.2 date monyy5.;
run;;

/* adjust labelattrs */
proc sgplot data=grpstocks;
  title 'HIGHLOW and XAXISTABLE for IBM and Intel';
  highlow x=date high=high low=low / open=open close=close group=stock
    lineattrs=(thickness=2) y2axis highlabel=hilabel 
    LABELATTRS=(Color=blue Family=Arial Size=2pt 
        Style=Italic Weight=Bold);
  xaxis display=(nolabel) values=('01jan2005'd to '01jul2005'd by month);
  y2axis display=(nolabel) grid;
  keylegend /position=topright location=inside;
  xaxistable close/ title='Close' class=stock colorgroup=stock valueattrs=(color=black size=3pt);
run;

